@@ -76,7 +76,7 @@ class CategoryAdminForm(forms.ModelForm):
 
 class CategoryAdmin(TreeEditor, admin.ModelAdmin):
     form = CategoryAdminForm
-    list_display = ('__unicode__',)
+    list_display = ('name','order','alternate_title',)
     search_fields = (('name',))
     prepopulated_fields = {'slug': ('name',)}
     fieldsets = (
@@ -102,10 +102,19 @@ class CategoryAdmin(TreeEditor, admin.ModelAdmin):
 admin.site.register(Category, CategoryAdmin)
 
 for model,modeladmin in admin.site._registry.items():
-    if model in registry.values():
-        admin.site.unregister(model)
-        admin.site.register(model, type('newadmin', (modeladmin.__class__,), {
-            'fieldsets': getattr(modeladmin, 'fieldsets', ()) + (('Categories',{
-                'fields': [cat.split('.')[1] for cat in registry]
-            }),)
-        }))
\ No newline at end of file
+    if model in registry.values() and modeladmin.fieldsets:
+        fieldsets = getattr(modeladmin, 'fieldsets', ())
+        fields = [cat.split('.')[1] for cat in registry]
+        # check each field to see if already defined
+        for cat in fields:
+            for k,v in fieldsets:
+                if cat in v['fields']:
+                    fields.remove(cat)
+        # if there are any fields left, add them under the categories fieldset
+        if len(fields) > 0:
+            admin.site.unregister(model)
+            admin.site.register(model, type('newadmin', (modeladmin.__class__,), {
+                'fieldsets': fieldsets + (('Categories',{
+                    'fields': fields
+                }),)
+            }))
\ No newline at end of file
